==> v1.0.1.tar.gz: tesseract.js/docs/tesseract_lang_list.md <==
# Tesseract Languages

The `lang` property of the options object passed to `Tesseract.recognize` can have one of the following values (the default is `'eng'`.):

| `lang`    | Language              | 
|-----------|-----------------------| 
| 'afr'     | Afrikaans             | 
| 'ara'     | Arabic                | 
| 'aze'     | Azerbaijani           | 
| 'bel'     | Belarusian            | 
| 'ben'     | Bengali               | 
| 'bul'     | Bulgarian             | 
| 'cat'     | Catalan               | 
| 'ces'     | Czech                 | 
| 'chi_sim' | Chinese               | 
| 'chi_tra' | Traditional Chinese   | 
| 'chr'     | Cherokee              | 
| 'dan'     | Danish                | 
| 'deu'     | German                | 
| 'ell'     | Greek                 | 
| 'eng'     | Enlish                | 
| 'enm'     | English (Old)         | 
| 'epo'     | Esperanto             | 
| 'epo_alt' | Esperanto alternative | 
| 'equ'     | Math                  | 
| 'est'     | Estonian              | 
| 'eus'     | Basque                | 
| 'fin'     | Finnish               | 
| 'fra'     | French                | 
| 'frk'     | Frankish              | 
| 'frm'     | French (Old)          | 
| 'glg'     | Galician              | 
| 'grc'     | Ancient Greek         | 
| 'heb'     | Hebrew                | 
| 'hin'     | Hindi                 | 
| 'hrv'     | Croatian              | 
| 'hun'     | Hungarian             | 
| 'ind'     | Indonesian            | 
| 'isl'     | Icelandic             | 
| 'ita'     | Italian               | 
| 'ita_old' | Italian (Old)         | 
| 'jpn'     | Japanese              | 
| 'kan'     | Kannada               | 
| 'kor'     | Korean                | 
| 'lav'     | Latvian               | 
| 'lit'     | Lithuanian            | 
| 'mal'     | Malayalam             | 
| 'mkd'     | Macedonian            | 
| 'mlt'     | Maltese               | 
| 'msa'     | Malay                 | 
| 'nld'     | Dutch                 | 
| 'nor'     | Norwegian             | 
| 'pol'     | Polish                | 
| 'por'     | Portuguese            | 
| 'ron'     | Romanian              | 
| 'rus'     | Russian               | 
| 'slk'     | Slovakian             | 
| 'slv'     | Slovenian             | 
| 'spa'     | Spanish               | 
| 'spa_old' | Old Spanish           | 
| 'sqi'     | Albanian              | 
| 'srp'     | Serbian (Latin)       | 
| 'swa'     | Swahili               | 
| 'swe'     | Swedish               | 
| 'tam'     | Tamil                 | 
| 'tel'     | Telugu                | 
| 'tgl'     | Tagalog               | 
| 'tha'     | Thai                  | 
| 'tur'     | Turkish               | 
| 'ukr'     | Ukrainian             | 
| 'vie'     | Vietnamese            |

==> v1.0.14.tar.gz: tesseract.js/docs/tesseract_lang_list.md <==
# Tesseract Languages

The `lang` property of the options object passed to `Tesseract.recognize` can have one of the following values (the default is `'eng'`.):

| `lang`    | Language              | 
|-----------|-----------------------| 
| 'afr'     | Afrikaans             | 
| 'ara'     | Arabic                | 
| 'aze'     | Azerbaijani           | 
| 'bel'     | Belarusian            | 
| 'ben'     | Bengali               | 
| 'bul'     | Bulgarian             | 
| 'cat'     | Catalan               | 
| 'ces'     | Czech                 | 
| 'chi_sim' | Chinese               | 
| 'chi_tra' | Traditional Chinese   | 
| 'chr'     | Cherokee              | 
| 'dan'     | Danish                | 
| 'deu'     | German                | 
| 'ell'     | Greek                 | 
| 'eng'     | English                | 
| 'enm'     | English (Old)         | 
| 'epo'     | Esperanto             | 
| 'epo_alt' | Esperanto alternative | 
| 'equ'     | Math                  | 
| 'est'     | Estonian              | 
| 'eus'     | Basque                | 
| 'fas'     |Persian (Farsi)        |
| 'fin'     | Finnish               | 
| 'fra'     | French                | 
| 'frk'     | Frankish              | 
| 'frm'     | French (Old)          | 
| 'glg'     | Galician              | 
| 'grc'     | Ancient Greek         | 
| 'heb'     | Hebrew                | 
| 'hin'     | Hindi                 | 
| 'hrv'     | Croatian              | 
| 'hun'     | Hungarian             | 
| 'ind'     | Indonesian            | 
| 'isl'     | Icelandic             | 
| 'ita'     | Italian               | 
| 'ita_old' | Italian (Old)         | 
| 'jpn'     | Japanese              | 
| 'kan'     | Kannada               | 
| 'kor'     | Korean                | 
| 'lav'     | Latvian               | 
| 'lit'     | Lithuanian            | 
| 'mal'     | Malayalam             | 
| 'mkd'     | Macedonian            | 
| 'mlt'     | Maltese               | 
| 'msa'     | Malay                 | 
| 'nld'     | Dutch                 | 
| 'nor'     | Norwegian             | 
| 'pol'     | Polish                | 
| 'por'     | Portuguese            | 
| 'ron'     | Romanian              | 
| 'rus'     | Russian               | 
| 'slk'     | Slovakian             | 
| 'slv'     | Slovenian             | 
| 'spa'     | Spanish               | 
| 'spa_old' | Old Spanish           | 
| 'sqi'     | Albanian              | 
| 'srp'     | Serbian (Latin)       | 
| 'swa'     | Swahili               | 
| 'swe'     | Swedish               | 
| 'tam'     | Tamil                 | 
| 'tel'     | Telugu                | 
| 'tgl'     | Tagalog               | 
| 'tha'     | Thai                  | 
| 'tur'     | Turkish               | 
| 'ukr'     | Ukrainian             | 
| 'vie'     | Vietnamese            |
